@@ -9,6 +9,7 @@ from trytond.pool import Pool
 from webshop import WebShop, BannerCategory, Banner, Article
 from product import Product
 from invoice import Invoice
+from sale import Sale
 from party import Address
 from shipment import ShipmentOut
 
@@ -23,5 +24,6 @@ def register():
         Invoice,
         Address,
         ShipmentOut,
+        Sale,
         module='nereid_webshop', type_='model'
     )
